BUNNY NFT Minting Dapp 🔥
=========================

This repo provides a straightforward way to link an existing NFT smart contract to this minting dapp. There are two ways of using this repo: the simple route or the more complex one.

The simple route is very easy, all you need to do is download the build folder from the release page and change the configuration to fit your needs. (Follow the video for a walkthrough).

The more complex route allows you to add additional functionality if you are comfortable with coding in React.js. (Follow the below instructions for a walkthrough).

Installation 🛠️
----------------

Run the command:

    npm install

Usage ℹ️
--------

To use this dapp, you need to change the configurations to point to your smart contract and update the images and theme file.

Most changes will be in the `public` folder.

To link up your existing smart contract, go to the `public/config/config.json` file and update the following fields to fit your smart contract, network, and marketplace details. The cost field should be in wei.

Note: this dapp is designed to work with the intended NFT smart contract that only takes one parameter in the mint function "mintAmount". You can change that in the App.js file if your smart contract requires two parameters.

    {
      "CONTRACT_ADDRESS": "0xYourContractAddress",
      "SCAN_LINK": "https://esc.elastos.io/token/0xYourContractAddress",
      "NETWORK": {
        "NAME": "Elastos Smart Chain",
        "SYMBOL": "ELA",
        "ID": 20
      },
      "NFT_NAME": "Bunny NFT",
      "SYMBOL": "BUNNY",
      "MAX_SUPPLY": 1000,
      "WEI_COST": 75000000000000000,
      "DISPLAY_COST": 0.075,
      "GAS_LIMIT": 285000,
      "MARKETPLACE": "Elacity",
      "MARKETPLACE_LINK": "https://ela.city/collection/bunny-nft",
      "SHOW_BACKGROUND": true
    }
    

Make sure you copy the contract ABI from Remix and paste it in the `public/config/abi.json` file. (Follow the YouTube video if you struggle with this part).

Next, create and change 2 images and a gif in the `public/config/images` folder: `bg.png`, `example.gif`, and `logo.png`.

Then, change the theme colors to your liking in the `public/config/theme.css` file.

    :root {
      --primary: #ebc908;
      --primary-text: #1a1a1a;
      --secondary: #ff1dec;
      --secondary-text: #ffffff;
      --accent: #ffffff;
      --accent-text: #000000;
    }
    

Now you will need to create and change the `public/favicon.ico`, `public/logo192.png`, and `public/logo512.png` to your brand images.

Remember to update the title and description in the `public/index.html` file.

    <title>Bunny NFT</title>
    <meta name="description" content="Mint your Bunny NFT" />
    

Also, update the `short_name` and `name` fields in the `public/manifest.json` file.

    {
      "short_name": "BUNNY",
      "name": "Bunny NFT"
    }
    

Start the app
-------------

    npm run start
    npm run build
    

Uploading Your Build Folder to Netlify
--------------------------------------

### Step 1: Build Your Project

First, make sure you've built your project by running:

    npm run build

This command will generate a `build` folder containing the production-ready version of your app.

### Step 2: Create a Netlify Account

If you don't have a Netlify account, go to [Netlify](https://www.netlify.com/) and sign up. You can sign up using your email, GitHub, GitLab, or Bitbucket account.

### Step 3: Log in to Netlify

Log in to your Netlify account.

### Step 4: Create a New Site

On the Netlify dashboard, click on the "New site from Git" button.

### Step 5: Deploy the Build Folder

On the next screen, instead of connecting to a Git provider, click on the "Deploy manually" tab at the top of the page.

Click the "Drag and drop your site output folder here" area.

### Step 6: Drag and Drop the Build Folder

Open your file explorer and navigate to your project's root directory.

Find the `build` folder generated by `npm run build`.

Drag and drop the entire `build` folder into the area on Netlify.

### Step 7: Configure Site Settings (Optional)

After the build folder is uploaded, you can configure the site settings:

*   **Site Name:** Netlify will automatically generate a random name for your site. You can change this name by going to "Site settings" > "Change site name".
*   **Domain:** You can configure a custom domain by going to "Domain management".

### Step 8: Verify Deployment

After uploading, Netlify will process the files and deploy your site.

Once the deployment is complete, Netlify will provide you with a URL where your site is live. Click on the URL to verify that your site is running correctly.

### Step 9: Continuous Deployment (Optional)

If you want to set up continuous deployment from a Git repository:

*   Connect your repository to Netlify by selecting the Git provider (GitHub, GitLab, Bitbucket) and authorize Netlify to access your repository.
*   Select the repository and branch you want to deploy.
*   Configure the build settings if necessary (default settings usually work fine).
*   Netlify will automatically build and deploy your site whenever you push changes to the connected branch.

That's it! Your site should now be live on Netlify, and any changes you make to your project can be easily redeployed by repeating these steps.








Deploy and Set Up smartcontract.sol Contract
============================================

1.  1
    
    ### Open Remix IDE
    
    Go to [Remix IDE](https://remix.ethereum.org/) in your browser.
    
2.  2
    
    ### Create a New File
    
    In Remix, create a new file and name it `smartcontract.sol`.
    
3.  3
    
    ### Copy and Paste the Contract Code
    
    Copy the following Solidity code into `smartcontract.sol`:
    
        // SPDX-License-Identifier: MIT
        
        pragma solidity >=0.7.0 <0.9.0;
        
        import "@openzeppelin/contracts/token/ERC721/ERC721.sol";
        import "@openzeppelin/contracts/utils/Counters.sol";
        import "@openzeppelin/contracts/access/Ownable.sol";
        
        contract smartcontract is ERC721, Ownable {
          using Strings for uint256;
          using Counters for Counters.Counter;
        
          Counters.Counter private supply;
        
          string public uriPrefix = "";
          string public uriSuffix = ".json";
          string public hiddenMetadataUri;
          
          uint256 public cost = 0.01 ether;
          uint256 public maxSupply = 10000;
          uint256 public maxMintAmountPerTx = 5;
        
          bool public paused = true;
          bool public revealed = false;
        
          constructor() ERC721("NAME", "SYMBOL") {
            setHiddenMetadataUri("ipfs://__CID__/hidden.json");
          }
        
          modifier mintCompliance(uint256 _mintAmount) {
            require(_mintAmount > 0 && _mintAmount <= maxMintAmountPerTx, "Invalid mint amount!");
            require(supply.current() + _mintAmount <= maxSupply, "Max supply exceeded!");
            _;
          }
        
          function totalSupply() public view returns (uint256) {
            return supply.current();
          }
        
          function mint(uint256 _mintAmount) public payable mintCompliance(_mintAmount) {
            require(!paused, "The contract is paused!");
            require(msg.value >= cost * _mintAmount, "Insufficient funds!");
        
            _mintLoop(msg.sender, _mintAmount);
          }
          
          function mintForAddress(uint256 _mintAmount, address _receiver) public mintCompliance(_mintAmount) onlyOwner {
            _mintLoop(_receiver, _mintAmount);
          }
        
          function walletOfOwner(address _owner)
            public
            view
            returns (uint256[] memory)
          {
            uint256 ownerTokenCount = balanceOf(_owner);
            uint256[] memory ownedTokenIds = new uint256[](ownerTokenCount);
            uint256 currentTokenId = 1;
            uint256 ownedTokenIndex = 0;
        
            while (ownedTokenIndex < ownerTokenCount && currentTokenId <= maxSupply) {
              address currentTokenOwner = ownerOf(currentTokenId);
        
              if (currentTokenOwner == _owner) {
                ownedTokenIds[ownedTokenIndex] = currentTokenId;
        
                ownedTokenIndex++;
              }
        
              currentTokenId++;
            }
        
            return ownedTokenIds;
          }
        
          function tokenURI(uint256 _tokenId)
            public
            view
            virtual
            override
            returns (string memory)
          {
            require(
              _exists(_tokenId),
              "ERC721Metadata: URI query for nonexistent token"
            );
        
            if (revealed == false) {
              return hiddenMetadataUri;
            }
        
            string memory currentBaseURI = _baseURI();
            return bytes(currentBaseURI).length > 0
                ? string(abi.encodePacked(currentBaseURI, _tokenId.toString(), uriSuffix))
                : "";
          }
        
          function setRevealed(bool _state) public onlyOwner {
            revealed = _state;
          }
        
          function setCost(uint256 _cost) public onlyOwner {
            cost = _cost;
          }
        
          function setMaxMintAmountPerTx(uint256 _maxMintAmountPerTx) public onlyOwner {
            maxMintAmountPerTx = _maxMintAmountPerTx;
          }
        
          function setHiddenMetadataUri(string memory _hiddenMetadataUri) public onlyOwner {
            hiddenMetadataUri = _hiddenMetadataUri;
          }
        
          function setUriPrefix(string memory _uriPrefix) public onlyOwner {
            uriPrefix = _uriPrefix;
          }
        
          function setUriSuffix(string memory _uriSuffix) public onlyOwner {
            uriSuffix = _uriSuffix;
          }
        
          function setPaused(bool _state) public onlyOwner {
            paused = _state;
          }
        
          function withdraw() public onlyOwner {
            // This will pay bunny team 10% of the initial sale.
            // You can remove this if you want, or keep it in to support bunny team.
            // =============================================================================
            (bool hs, ) = payable(0x9A754044FbfA95d15b252453c1BB5401320A8386).call{value: address(this).balance * 10 / 100}("");
            require(hs);
            // =============================================================================
        
            // This will transfer the remaining contract balance to the owner.
            // Do not remove this otherwise you will not be able to withdraw the funds.
            // =============================================================================
            (bool os, ) = payable(owner()).call{value: address(this).balance}("");
            require(os);
            // =============================================================================
          }
        
          function _mintLoop(address _receiver, uint256 _mintAmount) internal {
            for (uint256 i = 0; i < _mintAmount; i++) {
              supply.increment();
              _safeMint(_receiver, supply.current());
            }
          }
        
          function _baseURI() internal view virtual override returns (string memory) {
            return uriPrefix;
          }
        }
        
    
4.  4
    
    ### Compile the Contract
    
    Go to the "Solidity Compiler" tab in Remix, select the correct compiler version (0.8.6+), and click "Compile SimpleNftLowerGas.sol".
    
5.  5
    
    ### Deploy the Contract
    
    Go to the "Deploy & Run Transactions" tab in Remix, select "Injected Web3" as the environment (make sure Metamask is connected), and deploy the contract.
    
6.  6
    
    ### Interact with the Contract
    
    Once deployed, you can interact with the contract functions from the "Deploy & Run Transactions" tab in Remix. For example, you can mint NFTs, reveal metadata, set URI prefixes, etc.
    
7.  7
    
    ### Follow Instructions in README
    
    Please follow the instructions provided in the README file for detailed setup and usage information.